<?php
/** Capiznon (Capiceño)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Capisano
 * @author Oxyzen
 * @author Reedy
 */

$messages = array(
# User preference toggles
'tog-underline' => 'Kuritan sa idalum ang mga link',
'tog-justify' => 'Tadlungon ang mga talata',
'tog-hideminor' => 'Itago ang mga gamay nga ginliwat sang mini lang ginbag-o',
'tog-hidepatrolled' => 'Itago ang mga napatrolya nga mga na-islan sang mini lang ginbag-o',
'tog-newpageshidepatrolled' => 'Itago ang mga napatrolya nga mga pahina halin sa bag-o nga lista sang pahina',
'tog-extendwatchlist' => 'Palapadon ang lista sang mga ginabantayan para makita ang tanan nga nagla-in, indi lang man ang pinakabag-o',
'tog-usenewrc' => 'Gamiton ang ginpatahum nga mga bag-ong ilis {kinanglan ang Javascript}',
'tog-numberheadings' => 'Insigida nga pag-isip sang numero sa mga titulo',
'tog-showtoolbar' => 'Ipakita ang toolbar sang pag-ilis (kinahanglan ang JavaScript)',
'tog-editondblclick' => 'Liwaton ang mga pahina sa duwa ka pindot {kinahanglan ang Javascript}',
'tog-editsection' => 'Pasugtan ang pagilis sang mga seksyon pamaagi sa mga [ilis] nga link',
'tog-editsectiononrightclick' => 'Pasugtan ang pag-ilis sang mga bahin pama-agi sa tu-o nga pagpindot sa mga titulo sang pahina {kinanglan ang JavaScript}',
'tog-showtoc' => 'Ipakita ang listahan sang mga kaundan (sa mga pahina nga may madamu pa sa 3 ka titulo)',
'tog-rememberpassword' => 'Dumduma ang pagsulod ko sa mini nga kompyuter (pinakadamu na ang $1 {{PLURAL:$1|adlaw|mga adlaw}})',
'tog-watchcreations' => 'Idugang sa akon balantayan ang mga pahina nga gin-ubra ko.',
'tog-watchdefault' => 'Idugang sa akon balantayan ang mga pahina nga akon na-islan',
'tog-watchmoves' => 'Idugang sa akon balantayan ang mga pahina nga akon ginsaylo',
'tog-watchdeletion' => 'Idugang sa akon balantayan ang mga pahina nga akon ginpanas',
'tog-minordefault' => 'Markahan ang tanan nga gin-islan nga gamay lang pamaagi sa default',
'tog-previewontop' => 'Ipakita ang prebyu antes ang kahon sang pang-ilis',
'tog-previewonfirst' => 'Ipakita ang prebyu sa una nga pag-ilis',
'tog-nocache' => 'Indi pagpaganahon ang pagcache sang pahina',
'tog-enotifwatchlistpages' => 'Padal-an ako sang email kung ang pahina sa akon ginabanatayan nagbag-o',
'tog-enotifusertalkpages' => 'Padal-an ako sang email kung ginbag-o ang akon nga pahina sang istoryahanay',
'tog-enotifminoredits' => 'Padal-an man ako sang email sa mga gamay nga pag-ilis sang mini nga pahina',
'tog-enotifrevealaddr' => 'Ipakita ang address sang akon email sa notipikasyon sang mga email',
'tog-shownumberswatching' => 'Ipakita ang mga numero sang mga gatan-aw nga manug-usar',
'tog-oldsig' => 'Nagkayara nga pirma:',
'tog-fancysig' => 'Ituring ang pirma bilang teksto sang wiki (wala sang automatik nga link)',
'tog-uselivepreview' => 'Maggamit sang buhi nga prebyu (kinanglan ang Javascript) (Eksperimental)',
'tog-forceeditsummary' => 'Hambalan ako kung nagapasulod sang wala unod nga pag-ilis kabilugan',
'tog-watchlisthideown' => 'Itago ang akon mga pagbag-o halin sa listahan sang mga ginabantayan',
'tog-watchlisthidebots' => 'Itago ang mga pagbag-o sang mga bot halin sa listahan ng mga ginabantayan',
'tog-watchlisthideminor' => 'Itago ang mga gamay nga pagbag-o halin sa listahan sang mga ginabantayan',
'tog-watchlisthideliu' => 'Tagu-on ang mga pag-ilis sang mga nagsulod nga mga manug-usar halin sa listahan sang mga ginabantayan',
'tog-watchlisthideanons' => 'Tagu-on ang mga pagbag-o sang wala nakilal-an nga mga manug-usar halin sa listahan sang mga ginabantayan',
'tog-watchlisthidepatrolled' => 'Tagu-on ang napatrolya nga mga pagbag-o nga naghalin sa listahan sang mga ginabantayan',
'tog-ccmeonemails' => 'Padal-an ako sang mga kopya sang mga ginpadala ko nga email sa iban nga manug-usar',
'tog-diffonly' => 'Indi pag ipakita ang unod sang pahina sa idalum sang mga ginkala-in',
'tog-showhiddencats' => 'Ipakita ang mga nakatago nga kategorya',
'tog-norollbackdiff' => 'Dula-on ang mga ginkala-in pagkatapos ma-ubra ang pagligid pabalik sa una',

'underline-always' => 'Perme',
'underline-never' => 'Wala gid',
'underline-default' => 'Browser nga gintakda',

# Font style option in Special:Preferences
'editfont-style' => 'Ilisan ang ginasakupan sang istilo sang font:',
'editfont-default' => 'Browser nga gintakda',
'editfont-monospace' => 'Isa ka lak-ang nga font',
'editfont-sansserif' => 'Sans- serif nga font',
'editfont-serif' => 'Serif nga font',

# Dates
'sunday' => 'Dominggo',
'monday' => 'Lunes',
'tuesday' => 'Martes',
'wednesday' => 'Miyerkules',
'thursday' => 'Huwebes',
'friday' => 'Biyernes',
'saturday' => 'Sabado',
'sun' => 'Dom',
'mon' => 'Lun',
'tue' => 'Mar',
'wed' => 'Miy',
'thu' => 'Huw',
'fri' => 'Biy',
'sat' => 'Sab',
'january' => 'Enero',
'february' => 'Pebrero',
'march' => 'Marso',
'april' => 'Abril',
'may_long' => 'Mayo',
'june' => 'Hunyo',
'july' => 'Hulyo',
'august' => 'Agosto',
'september' => 'Setyembre',
'october' => 'Oktubre',
'november' => 'Nobyembre',
'december' => 'Disyembre',
'january-gen' => 'Enero',
'february-gen' => 'Pebrero',
'march-gen' => 'Marso',
'april-gen' => 'Abril',
'may-gen' => 'Mayo',
'june-gen' => 'Hunyo',
'july-gen' => 'Hulyo',
'august-gen' => 'Agosto',
'september-gen' => 'Septiyembre',
'october-gen' => 'Oktubre',
'november-gen' => 'Nobiyembre',
'december-gen' => 'Disyembre',
'jan' => 'Ene',
'feb' => 'Peb',
'mar' => 'Mar',
'apr' => 'Abr',
'may' => 'May',
'jun' => 'Hun',
'jul' => 'Hul',
'aug' => 'Ago',
'sep' => 'Sep',
'oct' => 'Okt',
'nov' => 'Nob',
'dec' => 'Dis',

# Categories related messages
'pagecategories' => '{{PLURAL:$1|Kategorya|Mga Kategorya}}',
'category_header' => 'Mga pahina sa kategorya nga "$1"',
'subcategories' => 'Mga subkategorya',
'category-media-header' => 'Mga midya sa kategorya nga "$1"',
'category-empty' => "''Ang mini nga kategorya wala nag-unod yanda sang pahina ukon midya''",
'hidden-categories' => '{{PLURAL:$1|Nakatago nga kategorya|Nakatago nga mga kategorya}}',
'hidden-category-category' => 'Nakatago nga mga kategorya',
'category-subcat-count' => '{{PLURAL:$2|Mini nga kategorya ang may pangduha nga kategorya gid lang. |Mini nga kategorya may ara sang mga gasunod {{PLURAL:$1|subkategorya|$1 mga subkategorya}}, sa $2 kabilugan.}}',
'category-subcat-count-limited' => 'Ang mini nga kategorya may ara sang nagasunod {{PLURAL:$1|ka subkategorya|$! ka mga subkategorya}}.',
'category-article-count' => '{{PLURAL:$2|Mini nga kategorya naga-unod lang gid sang gasunod nga pahina.|Ang mga gasunod nga{{PLURAL:$1|pahina|$1 mga pahina}} sa mini nga kategroya, sa $2 nga kabilugan.}}',
'category-article-count-limited' => 'Ang mga gasunod nga{{PLURAL:$1|ka pahina|$1 ka mga pahina}} ara yanda sa kategorya.',
'category-file-count' => '{{PLURAL:$2|Mini nga kategorya naga-unod lang gid sang gasunod nga file. |Ang mga gasunod nga {{PLURAL:$1|ka pahina|$1 ka mga pahina}} sa mini nga kategroya, sa $2 nga kabilugan.}}',
'category-file-count-limited' => 'Ang gasunod nga {{PLURAL:$1|ka file|$1 ka mga file}} ara sa yanda nga kategorya.',
'listingcontinuesabbrev' => 'padayon',
'index-category' => 'Na-index nga mga pahina',
'noindex-category' => 'Wala na-index nga mga pahina',
'broken-file-category' => 'Mga pahina nga may guba nga mga file links',

'about' => 'Nahanungod sa',
'article' => 'Pahina sang ka-undan',
'newwindow' => '(gabukas sa bag-o nga bintana)',
'cancel' => 'Kanselahon',
'moredotdotdot' => 'Madamu pa...',
'mypage' => 'Akon pahina',
'mytalk' => 'Akon pag-istoryahanay',
'anontalk' => 'Istoryahanay parte sa mini nga IP',
'navigation' => 'Nabigayson',
'and' => '&#32;kag',

# Cologne Blue skin
'qbfind' => 'Pangita-on',
'qbbrowse' => 'Pangita-on',
'qbedit' => 'Ilisan',
'qbpageoptions' => 'Mini nga pahina',
'qbmyoptions' => 'Akon mga pahina',
'qbspecialpages' => 'Pinasahi nga mga pahina',
'faq' => 'Mga perme napamangkot ("FAQ")',
'faqpage' => "Project:Mga perme napamangkot (''FAQ'')",

# Vector skin
'vector-action-addsection' => 'Magdugang sang topiko',
'vector-action-delete' => 'Panason',
'vector-action-move' => 'Isdogon',
'vector-action-protect' => 'Protektahan',
'vector-action-undelete' => 'Indi pag panason',
'vector-action-unprotect' => 'Islan ang proteksyon',
'vector-simplesearch-preference' => 'Paganahon ang ginpanami nga mga suhestiyon sa pagpangita (panit nga Vector lang)',
'vector-view-create' => 'Ubrahon',
'vector-view-edit' => 'Bag-uhon',
'vector-view-history' => 'Ipakita ang kasaysayan',
'vector-view-view' => 'Basahon',
'vector-view-viewsource' => 'Lantawon ang ginhalinan',
'actions' => 'Mga hulag',
'namespaces' => 'Mga lang-at ngalan',
'variants' => 'Mga pililian',

'errorpagetitle' => 'Sala/Error',
'returnto' => 'Balik sa $1.',
'tagline' => 'Halin sa {{SITENAME}}',
'help' => 'Tabang',
'search' => 'Pagpangita',
'searchbutton' => 'Magpangita',
'go' => 'Padayun',
'searcharticle' => 'Padayun',
'history' => 'Kasaysayan sang pahina',
'history_short' => 'Kasaysayan',
'updatedmarker' => 'na-update halin sang san-o ko lang nga pagbisita',
'printableversion' => 'Maimprenta nga bersyon',
'permalink' => 'Permanente nga tabid',
'print' => 'I-imprinta',
'view' => 'Llantawon',
'edit' => 'Bag-uhon',
'create' => 'Ubrahon',
'editthispage' => 'Islan mini nga pahina',
'create-this-page' => 'I-ubrahon ang mini nga pahina',
'delete' => 'Panason',
'deletethispage' => 'Panason ang mini nga pahina',
'undelete_short' => 'Suli-on ang pagpanas sang {{PLURAL:$1|isa ka pagbag-o|$1 ka mga pagbag-o}}',
'viewdeleted_short' => 'Tan-awon ang {{PLURAL:$1|isa ka ginpanas nga pagbag-o|$1 ka mga ginpanas nga pagbag-o}}',
'protect' => 'Protektahan',
'protect_change' => 'bag-uhon',
'protectthispage' => 'Protektahan ang mini nga pahina',
'unprotect' => 'Bag-uhon ang pagprotekta',
'unprotectthispage' => 'Bag-uhon ang ang pagprotekta sang mini nga pahina',
'newpage' => 'Bag-o nga pahina',
'talkpage' => 'Diskusyonan ang mini nga pahina',
'talkpagelinktext' => 'Istoryahanay',
'specialpage' => 'Pinasahi nga pahina',
'personaltools' => 'Mga pangkaugalingon nga galamiton',
'postcomment' => 'Bag-o nga seksyon',
'articlepage' => 'Ipakita ang pahina sang ka-undan',
'talk' => 'Diskusyon',
'views' => 'Mga dagway',
'toolbox' => 'Mga galamiton',
'userpage' => 'Tan-awon ang pahina sang manug-usar',
'projectpage' => 'Tan-awon ang pahina sang proyekto',
'imagepage' => 'Tan-awon ang pahina sang file',
'mediawikipage' => 'Tan-awon ang pahina sang mensahe',
'templatepage' => 'Tan-awon ang pahina sang templeyt',
'viewhelppage' => 'Tan-awona ang pahina sang pagtabang',
'categorypage' => 'Tan-awon ang pahina sang kategorya',
'viewtalkpage' => 'Tan-awon ang diskusyon',
'otherlanguages' => 'Sa iban nga linggwahe',
'redirectedfrom' => '(Gindirekta liwat halin sa $1)',
'redirectpagesub' => 'Pahina sang pagdirekta',
'lastmodifiedat' => 'Ang mini nga pahina ginbag-o lang sang $1, sang $2.',
'viewcount' => 'Nasudlan ang mini nga pahina sang {{PLURAL:$1|isa|$1}} ka beses.',
'protectedpage' => 'Ginaprotektahan nga pahina',
'jumpto' => 'Tumbo sa:',
'jumptonavigation' => 'nabigayson',
'jumptosearch' => 'pagpangita',
'view-pool-error' => 'Pasesnya, nasobrahan ka karga ang mga server yanda.
Sobra kadamo nga mga manug-usar ang gusto makita ang mini nga pahina.
Palihog maghulat sang madali gid lang antes mo tistingan nga sudlan liwat ang mini nga pahina.

$1',
'pool-timeout' => 'Nagahulat sang kandado ang pagpahuway',
'pool-queuefull' => 'Puno na ang pisan sang mga pila',
'pool-errorunknown' => 'Wala nabal-an nga kasal-anan',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage).
'aboutsite' => 'Tuhoy sa {{SITENAME}}',
'aboutpage' => 'Project:Nahanungod sa',
'copyright' => 'Ang unod bakante sa idalum sang $1',
'copyrightpage' => '{{ns:project}}:Kinamatarong sa pangpanag-iya',
'currentevents' => 'Mga yanda nga hitabo',
'currentevents-url' => 'Project: Mga yanda nga hitabo',
'disclaimers' => 'Mga pagpangindi',
'disclaimerpage' => 'Project:Pangkabilugan nga pagpangindi',
'edithelp' => 'Bulig sa pag-ilis',
'helppage' => 'Help:Mga ka-undan',
'mainpage' => 'Panguna nga pahina',
'mainpage-description' => 'Panguna nga pahina',
'policy-url' => 'Project:Patakaran',
'portal' => 'Kaladtu-an sang komunidad',
'portal-url' => 'Project:Kaladtu-an sang komunidad',
'privacy' => 'Patakaran sa pagkapribado',
'privacypage' => 'Project:Patakaran sa pagkapribado',

'badaccess' => 'Sala sa pagla-ong',
'badaccess-group0' => 'Indi ka pwede ubrahon ang aksyon nga imo ginla-ong.',
'badaccess-groups' => 'Limitado ang hulag nga ginpanagayo mo sa mga manug-usar sa {{PLURAL:$2|ka hubon|sa isa ka mga hubon}}: $1.',

'versionrequired' => 'Kinanglan ang $1 nga bersyon sang MediaWiki',
'versionrequiredtext' => 'Kinahanglan ang $1 nga bersyon sang MediaWiki para magamit ang mini nga pahina.
Tan-awon ang [[Special:Version|pahina sang bersyon]].',

'ok' => 'Sige',
'retrievedfrom' => 'Nakuha halin sa "$1"',
'youhavenewmessages' => 'May ara ka sang $1 ($2).',
'newmessageslink' => 'mga bag-o nga mensahe',
'newmessagesdifflink' => 'katapusan nga pag-ilis',
'youhavenewmessagesmulti' => 'May mga bag-o ka nga mensahe sa $1',
'editsection' => 'bag-uhon',
'editold' => 'bag-uhon',
'viewsourceold' => 'lantawon ang ginhalinan',
'editlink' => 'islan',
'viewsourcelink' => 'tan-awon ang ginhalinan',
'editsectionhint' => 'Bag-uhon mining bahin: $1',
'toc' => 'Mga ka-undan',
'showtoc' => 'ipakita',
'hidetoc' => 'tagu-on',
'collapsible-collapse' => 'Ilagbong',
'collapsible-expand' => 'Palapadon',
'thisisdeleted' => 'Tan-awon ukon ibalik ang sang una nga $1?',
'viewdeleted' => 'Tan-awon ang $1?',
'restorelink' => '{{PLURAL:$1|isa ka|$1}} pinanas nga ginbag-o',
'feedlinks' => 'Pa-on:',
'feed-invalid' => 'Sala nga sari sang sebisyo sang pagpaabot',
'feed-unavailable' => 'Wala sang serbisyo halin sa pa-on sang sindikasyon',
'site-rss-feed' => '$1 pa-on nga RSS',
'site-atom-feed' => '$1 pa-on nga Atom',
'page-rss-feed' => '"$1" ka pa-on nga RSS',
'page-atom-feed' => '"$1" ka pa-on nga Atom',
'red-link-title' => '$1 (indi buhi ang pahina)',
'sort-descending' => 'Pulupasunudon nga magpanaug',
'sort-ascending' => 'Pulupasunudon nga magsaka',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main' => 'Pahina',
'nstab-user' => 'Pahina sang manug-usar',
'nstab-media' => 'Pahina sang midya',
'nstab-special' => 'Pinasahi nga pahina',
'nstab-project' => 'Pahina sang katuyuan',
'nstab-image' => 'Akta',
'nstab-mediawiki' => 'Mensahe',
'nstab-template' => 'Templeyt',
'nstab-help' => 'Pahina sang tabang',
'nstab-category' => 'Kategorya',

# Main script and global functions
'nosuchaction' => 'Wala sang mina nga aksyon',
'nosuchactiontext' => 'Indi mabaton ang hulag nga ginhimo sang URL.
Posible nga nagsala ka sa pagtype sang URL, ukon nagsunod sa isa ka sala nga link.
Pwede man mini magpakita sang isa ka depekto nga ara sa sulod sang {{SITENAME}}.',
'nosuchspecialpage' => 'Wala sang mina nga pinasahi nga pahina',
'nospecialpagetext' => '<strong>Nagpangayo ikaw sang inbalido nga pinasahi nga pahina.</strong>

Ang listahan sang inbalido nga mga pinasahi nga pahina makit-an sa [[Special:SpecialPages|{{int:specialpages}}]].',

# General errors
'error' => 'Sala',
'databaseerror' => 'Diperensya sa database',
'laggedslavemode' => 'Pahibalo: Posible nga wala unod ang pahina sang mga yanda nga bag-ong nadugang.',
'readonly' => 'Nakakandado ang database',
'enterlockreason' => 'Maghatag sang kabangdanan sa pagkakandado, upod ang bana-bana kung san-o ang kandado ibuy-an',
'readonlytext' => 'Nakakandado yanda ang kalipunan sang datos para sa mga bago nga entrada kag iban pa nga mga pagbag-o, seguro para sa ulubrahon nga pangapagpasakdag sang kalipunan sang datos, magabalik ini sa normal pagkaagi sini.

Naghatag sang mini nga rason ang tagadumala nga nagkandado sini: $1',
'missing-article' => 'Wala makit-an sang kalipunan sang datos ang teksto sang isa ka pahina nga dapat matukiban sini, may ngalan nga "$1" $2.

Kinaandan tungod ini sa pagsunod sa isa ka wala sa panahon nga kinatuhay ukon tabid nga pangkasaysayan sa isa ka pahina nga napaksi.

Kung indi mini ang kaso, ayhan nakakita ikaw sang depekto sa software.
Palihog isugid ini sa isa ka [[Special:ListUsers/sysop|administrator]], samtang ginahatag ang URL.',
'missingarticle-rev' => '(pagbag-o#: $1)',
'missingarticle-diff' => '(Ginkala-in: $1, $2)',
'readonly_lag' => 'Otomatiko nga ginkandaduhan samtang ang serbidor sang alila nga database ginakwa pakadto sa pinakapuno',
'internalerror' => 'Pangsulodlon nga diperensiya',
'internalerror_info' => 'Pangsulodlon nga diperensiya:  $1',
'fileappenderrorread' => 'Indi mabasa ang "$1" samtang ginalakip.',
'fileappenderror' => 'Indi malakip ang "$1" sa "$2".',
'filecopyerror' => 'Indi makopya ang file nga "$1" pakadto sa "$2".',
'filerenameerror' => 'Indi mapangalanan liwat ang file nga "$1" pakadto sa "$2".',
'filedeleteerror' => 'Indi mapanas ang file nga "$1".',
'directorycreateerror' => 'Indi maka-ubra sang direktoryo nga "$1".',
'filenotfound' => 'Indi makita sang file nga "$1".',
'fileexistserror' => 'Indi makasulat sa file nga "$1": buhi ang file',
'unexpected' => 'Wala naekspektaran nga bili: "$1"="$2"',
'formerror' => 'Kasal-anan: indi mapadala ang pormas',
'badarticleerror' => 'Ang mini nga aksyon indi mahimo sa mini nga pahina.',
'cannotdelete' => 'Indi mapanas ang pahina ukon ang file nga "$1" .
Posible nga ginpanas na ini sang wala makilal-an.',
'cannotdelete-title' => 'Indi mapanas ang pahina nga "$1"',
'badtitle' => 'Kala-in nga titulo',
'badtitletext' => 'Ang ginapangayo nga titulo sang pahina sala, wala unod, ukon may indi insakto nga koneksyon sa inter-language ukon sa titulo sang interwiki.
Pwede nga naga-unod mini sang isa ukon madamo pa nga mga karakter nga indi pwede gamiton sa mga titulo.',
'perfcached' => 'Naka-cache ang mga gasunod nga pahina kag posible nga wala na sa panahon. {{PLURAL:$1|one result is|$1 results are}} ang pinakamataas nga bakante nga cache.',
'perfcachedts' => 'Nakacache ang gasunod nga datos, kag nagligad nga ginsapanahon sang $1. {{PLURAL:$4|ang|$4 ang}} pinakamataas nga bakante nga cache.',
'querypage-no-updates' => 'Ginbawalan yanda ang mga update sa mini nga pahina .
Ang data diya wala napreskuhan sang aktwal.',
'wrong_wfQuery_params' => 'Sala nga mga parametro sa wfQuery()<br />
Pulos: $1<br />
Pamangkot: $2',
'viewsource' => 'Tan-awon ang ginhalinan',
'viewsource-title' => 'Tan-awon ang ginhalinan para sa $1',
'actionthrottled' => 'Ginpunggan ang ulubrahon',
'actionthrottledtext' => 'Bilang pangontra spam nga mga pagsulundan, ginalimitahan ikaw sa pag-ubra sang mini nga mga aksyon sang madamo nga beses sa manubo nga oras, kag nagsobra ka na sa limitasyon.
Palihog tistingan liwat sa pila ka minutos.',
'protectedpagetext' => 'Ginkandaduhan ang mini nga pahina para indi ma-islan.',
'viewsourcetext' => 'Pwede mo makita kag makopya ang ginhalinan sang mini nga pahina:',
'protectedinterface' => "Nagahatag ang mini nga pahina sang teksto nga pangkatapusan (''interface'') para sa software, kag ikandado para mapunggan ang pag-abuso.",
'editinginterface' => "'''Paandam:''' gin-islan mo ang pahina nga gina-usar nga nagahatag teksto sang interface sa sopwer.
Makaapekto ang mga gin-islan sa mini nga pahina sa gwaan nga itsura ka interface sang manug-usar sa iban nga mga manug-usar.
Para sa mga pagtransleyt, palihog konsidera gamit ang [http://translatewiki.net/wiki/Main_Page?setlang=en translatewiki.net], ang MediaWiki proyekto sa paglokalisa.",
'cascadeprotected' => 'Ginprotektahan ang mini nga pahina sa pagpangilis, tungod naupod ini sa mga gasunod nga {{PLURAL:$1|pahina, nga|mga pahina, nga}} protektado upod ang "cascading" nga pilili-an nga naga-andar:
$2',
'namespaceprotected' => "Wala ka sang permiso nga magliwat sang mga pahina nga ara sa namespace nga '''$1'''.",
'ns-specialprotected' => 'Indi pwede bag-uhon ang mga pinasahi nga pahina.',
'titleprotected' => 'Naprotektahan ang mini nga titulo halin sa pag-ubra ni [[User:$1|$1]].
Mini ang ginhatag nga kabangdanan "\'\'$2\'\'".',

# Virus scanner
'virus-badscanner' => "Sala nga konpigurasyon: wala nakilal-an nga manugsala sang virus: ''$1''",
'virus-scanfailed' => 'palpak ang pagscan (code $1)',
'virus-unknownscanner' => 'wala makilal-an nga pangontra-bayrus:',

# Login and logout pages
'logouttext' => "'''Nakagwa ka na.'''

Pwede mo mapadayon usar ang {{SITENAME}}, ukon pwede ka <span class='plainlinks'>[$1 lmagsulod liwat]</span> bilang pareho ukon la-in nga manug-usar.
Tandaan nga ang iban nga pahina magapadayon nga ipakita nga nakasulod ka man gyapon kuno abi, asta panason mo ang cache sang imo browser.",
'yourname' => 'Hayo (username):',
'yourpassword' => 'Password:',
'yourpasswordagain' => 'Liwata ka pindot ang password:',
'remembermypassword' => 'Dumduma ang pagsulod ko sa mini nga kompyuter (pinakadamu na ang $1 {{PLURAL:$1|adlaw|mga adlaw}})',
'yourdomainname' => 'Imo domain:',
'login' => 'Mag sulod',
'nav-login-createaccount' => 'Magsulod / mag-ubra sang account',
'loginprompt' => 'Dapat nakabukas ang cookies para makasulod sa {{SITENAME}}.',
'userlogin' => 'Mag sulod / mag-ubra account',
'userloginnocreate' => 'Magsulod',
'logout' => 'Maggwa',
'userlogout' => 'Maggwa',
'notloggedin' => 'Wala nakasulod',
'nologin' => "Wala ka account? '''$1'''.",
'nologinlink' => 'Mag-ubra account',
'createaccount' => 'Mag-ubra account',
'gotaccount' => "May account ka na bala? '''$1'''.",
'gotaccountlink' => 'Magsulod',
'createaccountmail' => 'Paagi sa email',
'badretype' => 'Wala gasanto ang password nga imo ginsulod',
'userexists' => 'May naga-usar na sang ginpasulod nga ngalan manug-usar.
Magpili sang iban nga ngalan.',
'loginerror' => 'Sala sa pagsulod',
'createaccounterror' => 'Indi mahimo ang acount nga: $1',
'noname' => 'Wala mo nahatag ang tsakto nga ngalan sang manug-usar.',
'nouserspecified' => 'Kinanglan mo ihatag sang insakto ang ngalan sang manug-usar.',
'wrongpassword' => 'Sala nga pagsulod sang password.
Palihog tistingan liwat.',
'wrongpasswordempty' => 'Wala unod ang password nga ginsulod.
Palihog tistingan liwat.',
'passwordtooshort' => 'Ang password dapat biskan {{PLURAL:$1|1 ka karakter|$1 ka mga karakter}}.',
'password-name-match' => 'Dapat la-in ang imo password sa imo ngalan manug-usar.',
'mailmypassword' => 'I-email ang bag-o nga password',
'passwordremindertitle' => 'Bag-ong temporaryo nga password para sa {{SITENAME}}',
'noemail' => 'Wala sang address sang email nga nakalista para sa manug-usar nga "$1".',
'noemailcreate' => 'Kinahanglan mo maghatag sang pwede nga address sang email',
'mailerror' => 'Kasal-anan sa pagpadala sang email: $1',
'emailauthenticated' => 'Ang imo email address nakilal-an sang $2, $3.',
'noemailprefs' => 'Tukuyon ang isa ka address sang email sa imo mga ginapalabi para sa mini nga mga pitsi-pitsi para maggana.',
'emailconfirmlink' => 'Kumpirmahon ang imo address sang imo email.',
'accountcreated' => 'Nahimo na ang account',
'accountcreatedtext' => 'Nahimo na ang acount sang manug-usar para kay $1.',
'createaccount-title' => 'Paghimo sang account para sa {{SITENAME}}',
'usernamehasherror' => 'Ang ngalan sang manug-usar indi dapat mag-unod sang mga labay-labay nga mga karakter.',
'loginlanguagelabel' => 'Lingguahe:',

# Change password dialog
'resetpass' => 'Islan ang password',
'resetpass_header' => 'Islan ang password sang account',
'oldpassword' => 'Luma nga password:',
'newpassword' => 'Bag-ong password:',
'retypenew' => 'I-type liwat ang bag-o nga password:',
'resetpass_submit' => 'Itakda ang password kag magsulod',
'resetpass_forbidden' => 'Indi pwede ma-islan ang password',
'resetpass-no-info' => 'Nakasulod ka dapat para makadtu-an ang mini nga pahina sang diretso.',
'resetpass-temp-password' => 'Temporaryo nga password:',

# Edit page toolbar
'bold_sample' => 'Madukot nga teksto',
'bold_tip' => 'Madukot nga teksto',
'italic_sample' => 'Gahilay nga teksto',
'italic_tip' => 'Gahilay nga teksto',
'link_sample' => 'Titulo sang link',
'link_tip' => 'Sa sulod nga link',
'extlink_sample' => 'http://www.example.com titulo nga link',
'extlink_tip' => 'Halin sa gwa nga link (tandaan ang http:// nga prefiks)',
'headline_sample' => 'Teksto sang pangulong-dinalan',
'headline_tip' => 'Lebel 2 pangulong-dinalan',
'nowiki_sample' => 'Isal-ot ang wala na-format nga teksto diya',
'nowiki_tip' => 'Pabay-an ang wiki nga sulundan',
'image_tip' => 'Ginpilit nga file',
'media_tip' => 'Link sa file',
'sig_tip' => 'Imo pirma upod sang timestamp',
'hr_tip' => 'Gapahigda nga linya (gamiton sang laka)',

# Edit pages
'summary' => 'Kabilugan:',
'subject' => 'Ginatukoy/pangulong-dinalan:',
'minoredit' => 'Ini gamay nga pag-ilis',
'watchthis' => 'Bantayan mining pahina',
'savearticle' => 'I-save mining mga pahina',
'preview' => 'Prebyu',
'showpreview' => 'Ipakita ang preview',
'showdiff' => 'Ipakita ang inislan',
'anoneditwarning' => "'''Pa-andam:''' Wala ka pa nakasulod.
Igasulat ang imo IP adres sa historya sang mga inislan sang mini nga pahina.",
'missingcommenttext' => 'Palihog isulod ang komento sa idalum.',
'summary-preview' => 'Kabilugan nga prebyu:',
'newarticle' => '(Bag-o)',
'newarticletext' => "Ginsundan mo ang pahina nga wala pa gagana.
Para ubrahon ang pahina, umpisahan nga mag-type sa kahon sa idalum (tan-awon ang [[{{MediaWiki:Helppage}}|pahina sang tabang]] para sa madamo pa nga info).
Kung ari ka diya tungod sa sala, pinduton ang ('''back''') nga buton sang imo nga browser.",
'noarticletext' => 'Wala pa yanda sang teksto sa sulod sang mini nga pahina.
Sarang mo [[Special:Search/{{PAGENAME}}|pangitaon ang titulo sang mini nga pahina]] sa iban pa nga mga pahina,
<span class="plainlinks">[{{fullurl:{{#Special:Log}}|page={{FULLPAGENAMEE}}}} mangita ka sang pareho nga mga lilistahan],
o [{{fullurl:{{FULLPAGENAME}}|action=edit}} bag-uhon ang mini nga pahina]</span>.',
'noarticletext-nopermission' => 'Wala sang teksto yanda sa mini nga pahina.
Pwede mo nga [[Special:Search/{{PAGENAME}}|pulupangitaon ang titulo sang mini nga pahina]] sa iban nga mga pahina,
ukon <span class="plainlinks">[{{fullurl:{{#Special:Log}}|page={{FULLPAGENAMEE}}}} magpangita sa kaangot nga mga listahan]</span>.',
'previewnote' => "'''Tandaan nga prebyu lang mini.'''
Wala pa na-save ang imo mga gin-islan!",
'editing' => 'Gina-islan ang $1',
'editingsection' => 'Ginaliwat ang $1 (seksiyon)',
'copyrightwarning' => "Panumduma nga ang tanan nga nabulig sa {{SITENAME}} ginakonsidera nga i-release sa idalum sang $2 (lantawon ang $1 para sa mga detalye). Kung indi mo gusto ma-ilisan ang imo sinulatan sang wala lu-oy kag ginapalapta sang basta basta, indi na lang pag-ipasa diya.<br />Ginapromisahan mo man kami nga ikaw ang nagsulat mini, ukon ginkopya mo halin sa isa ka pampubliko nga domain ukon sa pareho nga mga libre nga kuluha-an. ' ' 'Indi pag-ipasa ang mga copyrighted nga ubra nga wala sing permiso! ' ' '",
'templatesused' => '{{PLURAL:$1|Templeyt|Mga templeyt}} nga gina-usar sa mini nga pahina:',
'templatesusedpreview' => '{{PLURAL:$1|ka templeyt|ka mga templeyt}} ang ginagamit sa mini nga prebyu:',
'template-protected' => '(protektado)',
'template-semiprotected' => '(medyo protektado)',
'hiddencategories' => 'Ang mini nga pahina myembro sang {{PLURAL:$1|1 ka nakatago nga kategorya|$1 ka mga nakatago nga kategorya}}:',
'permissionserrorstext-withaction' => 'Wala ka sang permiso para $2, sang mga gasunod {{PLURAL:$1|ka rason|ka mga rason}}:',

# Parser/template warnings
'post-expand-template-inclusion-warning' => 'Paandam: Tama kadaku sang takos sang sakop sang templeyt.
Indi pag-ilakip ang pila ka mga suleras.',
'post-expand-template-inclusion-category' => 'Mga pahina kung sa diin naglapaw ang kadakuon nga sakop sang templeyt',

# History pages
'viewpagelogs' => 'Tan-awon ang mga paglista para sa mini nga pahina',
'currentrev-asof' => 'Bag-o nga rebisyon sang $1 gid lang',
'revisionasof' => 'Pagbag-o halin sang $1',
'previousrevision' => '← Daan nga pagbag-o',
'nextrevision' => 'Mas bag-o nga pagbag-o →',
'currentrevisionlink' => 'Mga inislan yanda',
'cur' => 'yanda',
'last' => 'ulihi',
'histlegend' => "Ikumpara ang mga ginpili: markahi ang mga radyo buton sang mga bersyon para makumpara kag pinduton ang \"enter\" ukon ang buton sa idalum.<br />Pananda: '''({{int:cur}})''' = ang ginkala-in niya sa yanda nga rebisyon,
'''({{int:last}})''' = ang ginalain niya sa gapadayun nga rebisyon, '''{{int:minoreditletter}}''' = gamay nga pag-ilis.",
'history-fieldset-title' => 'Tulutan-awon sa kasaysayan',
'histfirst' => 'Pinaka-una',
'histlast' => 'Pinakabag-o',

# Revision deletion
'rev-delundel' => 'ipakita/itago',
'revdel-restore' => 'Bag-uhon ang lebel sang pagpakita',
'revdel-restore-deleted' => 'ginpanas nga mga pagbag-o',
'revdel-restore-visible' => 'makit-an nga mga ginpangbag-o',

# Merge log
'revertmerge' => 'Sipaksipakon',

# Diffs
'history-title' => 'Kasaysayan sang pagbag-o sang "$1"',
'lineno' => 'Linya $1:',
'compareselectedversions' => 'I-kumpara ang pinili-an nga mga rebisyon',
'editundo' => 'ibalik',

# Search results
'searchresults' => 'Resulta sang pagpangita',
'searchresults-title' => 'Resulta sang pagpangita para sa "$1"',
'searchresulttext' => 'Para sa madamu pa nga impormasyon parti sa pagpangita {{SITENAME}}, lantawa ang [[{{MediaWiki:Helppage}}|{{int:bulig}}]].',
'searchsubtitle' => 'Nagpangita ka para \'\'\'[[:$1]]\'\'\' ([[Special:Prefixindex/$1|tanan nga pahina gasugod sa "$1"]]{{int:pipe-separator}}[[Special:WhatLinksHere/$1|tanan nga pahina nga naga tabid kay "$1"]])',
'searchsubtitleinvalid' => "Ginapangita mo ang '''$1'''",
'notitlematches' => 'Wala sang pareho nga titulo sang pahina',
'notextmatches' => 'Wala sang pahina sang teksto nga pareho',
'prevn' => 'antes {{PLURAL:$1|$1}}',
'nextn' => 'dason {{PLURAL:$1|$1}}',
'prevn-title' => 'Nagligad nga $1 {{PLURAL:$1| resulta| mga resulta}}',
'nextn-title' => 'Dason nga $1 {{PLURAL:$1|ka resulta|ka mga resulta}}',
'shown-title' => 'Ipakita ang $1 {{PLURAL:$1|ka resulta|ka mga resulta}} sa kada pahina',
'viewprevnext' => 'Tan-awon ($1 {{int:pipe-separator}} $2) ($3)',
'searchmenu-new' => "'''Ubrahon ang pahina nga \"[[:\$1]]\" sa sini nga wiki!'''",
'searchprofile-articles' => 'Mga pahina sang ka-undan',
'searchprofile-project' => 'Mga pahina sang Tabang kag Katuyuan',
'searchprofile-images' => 'Multimidya',
'searchprofile-everything' => 'Tanan nga butang',
'searchprofile-advanced' => 'Mas mataas nga lebel',
'searchprofile-articles-tooltip' => 'Pangitaon sa $1',
'searchprofile-project-tooltip' => 'Pangitaon sa $1',
'searchprofile-images-tooltip' => 'Magpangita sang mga akta',
'searchprofile-everything-tooltip' => 'Pangitaon ang tanan nga kaundan (lakip ang mga pahina sang pag-istoryahanay)',
'searchprofile-advanced-tooltip' => 'Pangitaon sa ginpaubra nga mga lang-at pangalan',
'search-result-size' => '$1 ({{PLURAL:$2|1 ka tinaga|$2 ka mga tinaga}})',
'search-redirect' => '(i-ubay ang $1)',
'search-section' => '(seksyon nga $1)',
'search-suggest' => 'Ambot mo silingon: $1',
'search-interwiki-caption' => 'Mga utod nga proyekto',
'search-interwiki-default' => '$1 mga resulta:',
'search-interwiki-more' => '(mas damu pa)',
'searchall' => 'tanan',
'showingresultsheader' => "{{PLURAL:$5|Resulta nga '''$1''' sang '''$3'''|Mga resulta nga '''$1 - $2''' sang '''$3'''}} para sa '''$4'''",
'nonefound' => "'''Tandaan''': Ang iban lang nga mga ngalan-espasyo ang ginapangita depende sa gintakda.
Tistingan mo i-prefiks ang imo pamangkot upod sang ''tanan:'' para makita mo ang tanan nga unod (dala na dira ang pahina pag-istoryahanay, templeyts, etc), ukon gamita amg imo nanamian nga ngalan-espasyo bilang prefiks.",
'search-nonefound' => 'Wala sang mga resulta nga nagatugma sa pamangkot/pagpamangkot.',
'powersearch' => 'Abanse nga pagpangita',
'powersearch-legend' => 'Abanse nga pagpangita',
'powersearch-ns' => 'Magpangita sa mga espasyo sang pangalan:',
'powersearch-redir' => 'Lista sang mga gindirekta liwat',
'powersearch-field' => 'Pangita-on ang',

# Preferences page
'preferences' => 'Mga ginapalabi',
'mypreferences' => 'Akon mga ginapalabi',

# Groups
'group-sysop' => 'Mga manugdumala',

'grouppage-sysop' => '{{ns:project}}:Mga manugdumala',

# Special:Log/newusers
'newuserlogpage' => 'Listahan sang pag-ubra sang manug-usar',

# User rights log
'rightslog' => 'Lista sang mga karapatan sang manug-usar',

# Associated actions - in the sentence "You do not have permission to X"
'action-edit' => 'liwaton mini nga pahina',

# Recent changes
'nchanges' => '$1 {{PLURAL:$1|ka pagbag-o|ka mga pagbag-o}}',
'recentchanges' => 'Sining karon lang nga mga pagbag-o',
'recentchanges-legend' => 'Mga pilili-an sa bag-o lang na-islan',
'recentchanges-feed-description' => 'Sundon ang pinakabag-o nga nahimo sa wiki sa mini nga feed.',
'recentchanges-label-newpage' => 'Nag-ubra sang isa ka bag-o nga pahina ang mini nga pagbag-o',
'recentchanges-label-minor' => 'Gamay lang ini nga pagbag-o',
'recentchanges-label-bot' => 'Ubra sang isa ka bot ang mini nga pagbag-o',
'recentchanges-label-unpatrolled' => 'Wala pa napapatrulyahan ang mini nga pagbag-o',
'rcnote' => "Diya sa idalum may {{PLURAL:$1|'''1''' ka bag-o| '''$1''' ka mga nabag-o}} sang naligad nga {{PLURAL:$2|ka adlaw|'''$2''' ka adlaw}}, sang mini nga $5, $4.",
'rclistfrom' => 'Ipakita ang bag-o nga mga na-islan halin sa $1',
'rcshowhideminor' => '$1 gamay nga mga inislan',
'rcshowhidebots' => '$1 ka bots',
'rcshowhideliu' => '$1 ka mga gagamit nga naka-sulod',
'rcshowhideanons' => '$1 ang wala nakilal-an nga mga ga-usar',
'rcshowhidemine' => '$1 akon mga na-islan',
'rclinks' => 'Ipakita ang nagligad ka $1 nga nabag-o lang gid sang $2 ka adlaw<br  />$3',
'diff' => 'ginkala-in',
'hist' => 'kasaysayan',
'hide' => 'Itago',
'show' => 'Ipakita',
'minoreditletter' => 'minor',
'newpageletter' => 'B',
'boteditletter' => 'b',
'rc-enhanced-expand' => 'Ipakita ang mga detalye (kinahanglan sang JavaScript)',
'rc-enhanced-hide' => 'Tagu-on ang mga detalye',

# Recent changes linked
'recentchangeslinked' => 'Mga labot sa pag-ilis',
'recentchangeslinked-toolbox' => 'Mga kaangot nga pagbag-o',
'recentchangeslinked-title' => 'Mga lain nga may angot sa "$1"',
'recentchangeslinked-summary' => "Lista ini sining karon lang nga mga pagbag-o nga naubra sa mga pahina nga gintabid halin sa gintumod nga pahina (ukon mga katapu sang gintumod nga kategorya).
'''Madukot''' ang mga pahina sa imo lista sang ginabantayan sa [[Special:Watchlist|imo lista sang ginabantayan]].",
'recentchangeslinked-page' => 'Ngalan ka pahina:',
'recentchangeslinked-to' => 'Ipakita na lang ang la-in sa pahina nga gin-link sa ginhatag nga pahina',

# Upload
'upload' => 'Magkarga sang akta',
'uploadlogpage' => 'Lista sang upload',
'filedesc' => 'Kasumahan',
'uploadedimage' => 'na-upload ang "[[$1]]"',

'license' => 'Paglaong:',

# File description page
'file-anchor-link' => 'Akta',
'filehist' => 'Kasaysayan sang akta',
'filehist-help' => 'Pinduton sa may petsa/oras para makita ang file sa mina nga oras.',
'filehist-current' => 'yanda',
'filehist-datetime' => 'Petsa/Oras',
'filehist-thumb' => 'Thumbnail',
'filehist-thumbtext' => 'Thumbnail para sa bersyon halin sang $1',
'filehist-user' => 'Naga-usar',
'filehist-dimensions' => 'Mga takus',
'filehist-comment' => 'Kumento',
'imagelinks' => 'Pag-usar sang akta',
'linkstoimage' => 'Ang nagasunod {{PLURAL:$1|pahina nga nagalink|$1 mga pahina nga nagalink}} sa mini nga file:',
'sharedupload' => 'Ang mini nga file halin sa $1 kag pwede magamit sang iban pa nga mga proyekto.',
'sharedupload-desc-here' => 'Ang mini nga akta naga-umpisa sa $1 kag pwede usaron sa iban nga mga katuyuan.
Ang paglarawan nga yara sa ibabaw sang [$2 pahina sang paglarawan sang akta] sini didto ginapakita sa idalum.',
'uploadnewversion-linktext' => 'Mag-upload sang bag-o nga bersiyon sang mini nga file',

# Random page
'randompage' => 'Biskan ano nga pahina',

# Statistics
'statistics' => 'Mga estadistika',

# Miscellaneous special pages
'nbytes' => '$1 {{PLURAL:$1|ka byte|ka mga byte}}',
'nmembers' => '$1 {{PLURAL:$1|ka myembro|ka mga myembro}}',
'prefixindex' => 'Tanan nga mga pahina nga may prefiks',
'newpages' => 'Mga bag-o nga pahina',
'move' => 'Isdogon',
'movethispage' => 'Isdogon mining pahina',
'pager-newer-n' => '{{PLURAL:$1|mas bag-o nga 1|mas bag-o nga $1}}',
'pager-older-n' => '{{PLURAL:$1|mas daan nga 1|mas daan nga $1}}',

# Book sources
'booksources' => 'Mga makuhaan nga libro',
'booksources-search-legend' => 'Magpangita sa makuha-an nga mga libro',
'booksources-go' => 'Padayon',

# Special:Log
'log' => 'Mga Listahan',

# Special:AllPages
'allpages' => 'Tanan nga pahina',
'alphaindexline' => '$1 asta sa $2',
'prevpage' => 'Antes nga pahina ($1)',
'allpagesfrom' => 'Ipakita ang mga pahina halin sa:',
'allpagesto' => 'Ipakita ang mga pahina nga nagatapos sa:',
'allarticles' => 'Tanan nga pahina',
'allpagessubmit' => 'Padayun',

# Special:Categories
'categories' => 'Mga kategorya',

# Special:LinkSearch
'linksearch' => 'Panggwa nga mga link',

# Special:ListGroupRights
'listgrouprights-members' => '(lista sang mga myembro)',

# Email user
'emailuser' => 'I-email mini nga naga-usar',

# Watchlist
'watchlist' => 'Mga akon ginabantayan',
'mywatchlist' => 'Akon ginabantayan',
'addedwatchtext' => "Ang pahina nga \"[[:\$1]]\" gindugang na sa imo [[Special:Watchlist|ginabantayan]].
Ang mga pagbag-o sa buwas-damlag kag mga kaangot nga pahina sang istoryahanay pagalistahon diya, kag ang pahina maggwa nga '''madukot''' sa [[Special:RecentChanges|lista sang mga nagligad nga pagbag-o]] para mas mahapos makita.",
'removedwatchtext' => 'Ang pahina nga "[[:$1]]" ginkakas halin sa [[Special:Watchlist|imo lista sang ginabantayan]].',
'watch' => 'Bantayan',
'watchthispage' => 'Bantayan ang mini nga pahina',
'unwatch' => 'Di pagbantayan',
'watchlist-details' => '{{PLURAL:$1|$1 ka pahina|$1 ka mga pahina}} sa imo listahan sang ginabantayan, wala madala ang mga pahina sang istoryahanay.',
'wlshowlast' => 'Ipakita ang nagligad nga $1 ka mga oras $2 ka mga adlaw $3',
'watchlist-options' => 'Pililian para sa listahan sang mga ginabantayan',

# Displayed when you click the "watch" button and it is in the process of watching
'watching' => 'Ginabantayan...',
'unwatching' => 'Wala ginabantayan...',

# Delete
'deletepage' => 'Panason ang pahina',
'confirmdeletetext' => 'Imo na pagapanason ang isa ka pahina kaupod sang iya mga kasaysayan.
Palihog kumpirmahon nga intensyon mo nga himu-on mini, nga na-intindihan mo ang abtan, kag gina-ubra mo mini nga nagasunod sa [[{{MediaWiki:Policy-url}}|patakaran]].',
'actioncomplete' => 'Tapos na ang aksyon',
'deletedtext' => 'Napanas na ang "$1".
Tan-awon ang $2 para sa nalista sang mga bag-o lang napanas.',
'dellogpage' => 'Lista sang pagpanas',
'deletecomment' => 'Rason:',
'deleteotherreason' => 'Iban pa/dugang nga rason:',
'deletereasonotherlist' => 'Iban nga rason',

# Rollback
'rollbacklink' => 'paligidon pabalik sa (mas) nagligad',

# Protect
'protectlogpage' => 'Listahan sang proteksiyon',
'protectedarticle' => 'ginaprotektahan nga "[[$1]]"',
'modifiedarticleprotection' => 'binag-o nga lebel sang proteksiyon para sa "[[$1]]"',
'protectcomment' => 'Rason:',
'protectexpiry' => 'Maga-ekspayr sa:',
'protect_expiry_invalid' => 'Indi pwede ang oras sang pag-ekspayr.',
'protect_expiry_old' => 'Sang nagligad pa ang oras sang pag-ekspayr.',
'protect-text' => "Pwede mo malantaw kag mabag-o ang lebel sang proteksiyon diya para sa pahina nga '''$1'''.",
'protect-locked-access' => "Ang imo account wala nakala-ong para magpangbag-o sang proteksyon nga lebel sang pahina.
Ari ang mga mga settings yanda para sa pahina nga '''$1''':",
'protect-cascadeon' => 'Protektado ang mini nga pahina kay nasakop mini sa mga gasunod nga {{PLURAL:$1|pahina, nga may|mga pahina, nga may}} pasunod nga proteksiyon nga naga-andar.
Pwede mo mabag-o ang lebel sang proteksiyon sang mini nga pahina, pero indi ma-apektuhan ang pasunod nga proteksiyon.',
'protect-default' => 'Pasugtan ang tanan nga naga-usar',
'protect-fallback' => 'Kinahanglan sang pag-la-ong nga $1',
'protect-level-autoconfirmed' => 'Punggan ang bag-o kag di-rehistrado nga mga naga-usar',
'protect-level-sysop' => 'Mga gapamahala lang',
'protect-summary-cascade' => 'nagapasunod',
'protect-expiring' => 'Ma-ekspayr sa $1 (UTC)',
'protect-cascade' => 'Protektahan ang mga pahina nga ka-upod sa mini nga pahina (pasunod nga proteksiyon)',
'protect-cantedit' => 'Indi mo pwede mabag-o ang lebel sang proteksiyon sang mini nga pahina, kay wala ka nakala-ong para islan mini.',
'restriction-type' => 'Pahatnugot:',
'restriction-level' => 'Lebel sang pagbawal:',

# Undelete
'undeletelink' => 'tan-awon/ibalik',
'undeleteviewlink' => 'tan-awon',

# Namespace form on various pages
'namespace' => 'Lang-at ngalan:',
'invert' => 'Suli-on ang seleksyon',
'blanknamespace' => '(Panguna)',

# Contributions
'contributions' => 'Mga nabulig sang manug-usar',
'contributions-title' => 'Mga nabulig sang tagagamit nga si $1',
'mycontris' => 'Akon nabulig',
'contribsub2' => 'Para kay $1 ($2)',
'uctop' => '(ibabaw)',
'month' => 'Halin sa bulan (kag sa mas timprano):',
'year' => 'Halin sa tu-ig (kag sa mas timprano):',

'sp-contributions-newbies' => 'Ipakita lang gid ang mga kontribusyon sang mga bag-o nga account',
'sp-contributions-blocklog' => 'Lista sang pagbangga',
'sp-contributions-search' => 'Mangita sang mga nabulig',
'sp-contributions-username' => 'IP address ukon hayo (username):',
'sp-contributions-submit' => 'Pangita-on',

# What links here
'whatlinkshere' => 'Ang nagatabid diri',
'whatlinkshere-title' => 'Mga pahina nga naga-link sa $1',
'whatlinkshere-page' => 'Pahina:',
'linkshere' => "Ang mga gasunod nga pahina ga-link sa '''[[:$1]]''':",
'isredirect' => 'pahina pangdirekta',
'istemplate' => 'transklusyon',
'isimage' => 'Link sang litrato',
'whatlinkshere-prev' => '{{PLURAL:$1|antes|antes $1}}',
'whatlinkshere-next' => '{{PLURAL:$1|sunod|sunod nga $1}}',
'whatlinkshere-links' => '← mga link',
'whatlinkshere-hideredirs' => '$1 ka mga gindirekta liwat',
'whatlinkshere-hidetrans' => '$1 ang mga transklusyon',
'whatlinkshere-hidelinks' => '$1 ang mga link',
'whatlinkshere-filters' => 'Mga pangsala',

# Block/unblock
'blockip' => 'Punggan ang naga-usar',
'ipboptions' => '2 oras:2 hours,1 adlaw:1 day,3 adlaw:3 days,1 semana:1 week,2 semana:2 weeks,1 bulan:1 month,3 bulan:3 months,6 bulan:6 months,1 tu-ig:1 year,wala katapusan:infinite',
'ipblocklist' => 'Napunggan nga mga IP Address kag mga bansag (usernames)',
'blocklink' => 'lipdan/banggaan',
'unblocklink' => 'kuhaon ang paglipod',
'change-blocklink' => 'pagbag-o sang lipod',
'contribslink' => 'nabulig',
'blocklogpage' => 'Lista sang pagbangal',
'blocklogentry' => 'nabangga-an nga [[$1]] nga magatapos sa $2 $3',
'unblocklogentry' => 'di pagpunggan si $1',
'block-log-flags-nocreate' => 'pag-ubra sang account ginbawalan',

# Move page
'movepagetext' => "Gamit ang pormas sa idalum magala-in ang ngalan sang pahina, masaylo ang tanan nga kasaysayan niya sa bag-o niya nga pangalan.
Ang daan nga titulo mangin isa ka pahina sang pagdirekta sa bag-o nga titulo.
Pwede mo ma-update ang mga pagdirekta nga gakadto sa orihinal nga titulo sang diretso.
Kung indi mo gusto, siguraduhon nga may [[Special:DoubleRedirects|doble]] ukon [[Special:BrokenRedirects|bali nga pangdirekta]].
Ikaw ang responsable sa pagsiguro nga ang mga links nagapadayon sa pagtudlo kung sa diin sila dapat makadto.

Tandaan nga ang pahina '''indi''' masaylo kung may ara na sang pahina sa bag-o nga titulo, kung indi man wala mini sang unod ukon may pagdirekta kag wala mini sang nagligad nga kasayasayan sa pag-ilis.
Anbot silingon sini nga pwede mo man ma-islan ngalan ang pahina pabalik sa kung diin mini gin-ngalanan kung nagsala ikaw, kag indi mo matapakan sulat ang mini nga na-una nga pahina.

'''Paandam!'''
Mini mangin isa ka mala-in kag wala gina-ekspektaran nga pagbag-o para sa isa ka sikat nga pahina;
siguraduhon nga na-intyendihan mo ang paga-abtan sini antes magpadayun.",
'movepagetalktext' => "Ang na-upod nga pahina sang istoryahanay diretso nga ma-upod sa iya '''apang:'''
*Ang indi blangko ngapahina sang istoryahanay ara na nga bal-an sa idalum sa bag-o nga ngalan, ukon
*Wala mo nachekan ang mga kahon sa idalum.

Sa mga mini nga kaso, kinahanglan mo hulagon ang pahina nga ikaw mismo, kung gusto mo.",
'movearticle' => 'Sayluhon mining pahina:',
'newtitle' => 'Pakadto sa bag-o nga titulo:',
'move-watch' => 'Bantayan ang mini nga pahina',
'movepagebtn' => 'Sayluhon mini nga pahina',
'pagemovedsub' => 'Nadayon ang pagsaylo',
'movepage-moved' => '\'\'\'"Nasaylo na ang "$1" pakadto sa "$2"\'\'\'',
'articleexists' => 'May-ara na sang pahina nga kapareho sang imo titulo, ukon ang ngalan nga imo ginpili indi pwede.
Palihog pili liwat sang bag-o nga ngalan.',
'talkexists' => "'''Nasaylo na mismo ang mina nga pahina, pero ang pahina sang istoryahanay indi masaylo kay may ara na sang nakakuha sang bag-o nga titulo.
Palihog pakikombinar sa ila sang manomano.'''",
'movedto' => 'ginsaylo sa',
'movetalk' => 'Isaylo ang kaangot nga pahina sang istoryahanay',
'movelogpage' => 'Lista sang pagsaylo',
'movereason' => 'Rason:',
'revertmove' => 'ibalik',

# Export
'export' => 'Ipaalintonay ang mga pahina',

# Thumbnails
'thumbnail-more' => 'Padaku-on',

# Tooltip help for the actions
'tooltip-pt-userpage' => 'Ang imo kaugalingon nga pahina',
'tooltip-pt-mytalk' => 'Ang imo pahina sang pag-istoryahanay',
'tooltip-pt-preferences' => 'Akon mga ginapalabi',
'tooltip-pt-watchlist' => 'Ang lista sang mga pagbag-o sa mga pahina nga imo ginabantayan',
'tooltip-pt-mycontris' => 'Listahan sang imo nabulig',
'tooltip-pt-login' => 'Ginahagad ikaw nga magsulod, apang indi ini kinahanglan',
'tooltip-pt-logout' => 'Maggwa',
'tooltip-ca-talk' => 'Diskusyon tuhoy sa unod sang ini nga pahina',
'tooltip-ca-edit' => 'Sarang mo bag-uhon ang ini nga pahina. Palihog usara ang panunang tan-aw nga buton antes isagup.',
'tooltip-ca-addsection' => 'Mag-umpisa sang bag-o nga seksyon',
'tooltip-ca-viewsource' => 'Naprotektahan ang mini nga pahina.
Makit-an mo lang ang ginhalinan (source) sini.',
'tooltip-ca-history' => 'Nagligad nga bersyon sang mini nga pahina',
'tooltip-ca-protect' => 'Protektahan ang mini nga pahina',
'tooltip-ca-delete' => 'Panason mini nga pahina',
'tooltip-ca-move' => 'Isdogon mining pahina',
'tooltip-ca-watch' => 'Idugang mini nga pahina sa imo listahan sang pagabantayan',
'tooltip-ca-unwatch' => 'Kuhaon mini nga pahina sa imo lista sang ginabantayan',
'tooltip-search' => 'Magpangita sa {{SITENAME}}',
'tooltip-search-go' => 'Kadtu-an ang isa ka pahina nga may mini gid nga insakto nga pangalan.',
'tooltip-search-fulltext' => 'Pangita-on ang mga pahina para sa mini nga teksto',
'tooltip-p-logo' => 'Magkadto sa panguna nga pahina',
'tooltip-n-mainpage' => 'Magkadto sa panguna nga pahina',
'tooltip-n-mainpage-description' => 'Bisitahon ang panguna nga pahina',
'tooltip-n-portal' => 'Nahanungod sa proyekto, ano ang imo maubra, diin makita ang mga bagay-bagay.',
'tooltip-n-currentevents' => 'Magpangita sang basehan nga impormasyon nahanungod sa mga yanda nga hitabo',
'tooltip-n-recentchanges' => 'Ang listahan sang nagligad lang nga mga pagbag-o sa sulod sang wiki.',
'tooltip-n-randompage' => 'Magkarga sang biskan ano nga pahina',
'tooltip-n-help' => 'Lugar kung sa diin ini madiskubrihan',
'tooltip-t-whatlinkshere' => 'Listahan sang tanan nga pahina sang mga wiki nga nagatabid diri',
'tooltip-t-recentchangeslinked' => 'Sining karon lang nga mga pagbag-o nga nakatabid halin sa mini nga pahina',
'tooltip-feed-rss' => 'RSS feed para sa mini nga pahina',
'tooltip-feed-atom' => 'Paon nga Atom para sa mini nga pahina',
'tooltip-t-contributions' => 'Lantawon ang listahan sang mga nagbulig sang mini nga naga-usar',
'tooltip-t-emailuser' => 'Padal-an sang e-mail sa mini nga naga-usar',
'tooltip-t-upload' => 'Magkarga sang mga akta',
'tooltip-t-specialpages' => 'Listahan sang tanan nga mga pinasahi nga pahina',
'tooltip-t-print' => 'Maimprinta nga bersyon sang mini nga pahina',
'tooltip-t-permalink' => 'Permanente nga tabid sa mini nga pagbag-o sang pahina',
'tooltip-ca-nstab-main' => 'Tan-awon ang pahina sang kaundan',
'tooltip-ca-nstab-user' => 'Tan-awon ang pahina sang naga-usar',
'tooltip-ca-nstab-special' => 'Pinasahi mini nga pahina, indi mo ma-islan ang mismo nga pahina',
'tooltip-ca-nstab-project' => 'Tan-awon ang pahina sang katuyuan',
'tooltip-ca-nstab-image' => 'Tan-awon ang pahina sang akta',
'tooltip-ca-nstab-template' => 'Tan-awon ang templeyt',
'tooltip-ca-nstab-category' => 'Tan-awon ang pahina sang kategorya',
'tooltip-minoredit' => 'Markahan mini nga daw gamay lang nga pag-ilis',
'tooltip-save' => 'I-save imo ginpang-islan',
'tooltip-preview' => 'I-prebyu ang imo mga ginbag-o, palihog gamiton mo mini antes mo i-save!',
'tooltip-diff' => 'Ipakita ang mga gin-ubra mo nga bag-o sa teksto',
'tooltip-compareselectedversions' => 'Lantawa ang ginkala-in sang duwa ka napilian nga rebisyon sa mini nga pahina',
'tooltip-watch' => 'Idugang mini nga pahina sa imo lista nga ginabantayan',
'tooltip-rollback' => 'Ginabalik sang "Paligidon pabalik sa anay" ang (mga) pagbag-o sa mini nga pahina pakadto sa ulihi nga bersyon sang ulihi nga tagaambag paagi sa isa lang ka pindot.',
'tooltip-undo' => 'Ginabalik sang "Ibalik" ang pagbag-o nga ini kag ginabuksan ang pahina nga ulubrahan sang pagbag-o sa dagway nga pauna nga tan-aw anay.  Nagapasugot nga makadugang sang kabangdanan sa kasumahan.',
'tooltip-summary' => 'Maghatag sang malip-ot nga kasumahan',

# Browsing diffs
'previousdiff' => '← Mas daan nga na-islan',
'nextdiff' => 'Mas bag-o nga gin-islan →',

# Media information
'file-info-size' => '$1 × $2 piksel, kadakuon sang file: $3, klase sang MIME: $4',
'file-nohires' => 'Wala na sang mas mataas pa nga resolusyon (katin-aw).',
'svg-long-desc' => 'SVG file, nga ara sa $1 × $2 ka piksels, kadakuon sang file: $3',
'show-big-image' => 'Bilog nga resolusyon (katin-aw)',

# Bad image list
'bad_image_list' => 'Ang dagway amo ang mga nagasunod:

Mga nakalista nga bagay lang gid (mga linya nga nagasugod sa *) ang ginatagaan sang pagtalupangod.
Ang una nga tabid sa isa ka linya dapat nagatabid sa isa ka mala-in nga akta.
Anuman nga mga nagasunod nga tabid sa ginhalinan nga linya ginakabig nga mga pagkatuhay, i.e. mina nga mga pahina nga kung sa diin ang mga akta ginatugutan nga maglutaw sa sulod sang linya.',

# Metadata
'metadata' => 'Metadata',
'metadata-help' => 'Ang mini nga file naga-unod sang dugang nga impormasyon, posible nga gindugan halin sa digital camera ukon skaner nga gingamit ukon gin-digitize mini.
Kung ang file ginliwat halin sa orihinal nga porma, indi mapakita sang iban nga detalye ang mga ginbag-o nga file.',
'metadata-expand' => 'Ipakita ang mga dugang nga detalye',
'metadata-collapse' => 'Itago ang mga dugang nga detalye',
'metadata-fields' => 'Ang mga lugar sang EXIF metadata nga nalista sa mini nga mensahe pagadal-on sa mga laragway nga ginapakita sa pahina kung maguba ang tabla sang metadata.
Ang iban ay pagataguon sang default.
* make
* model
* datetimeoriginal
* exposuretime
* fnumber
* isospeedratings
* focallength
* artist
* copyright
* imagedescription
* gpslatitude
* gpslongitude
* gpsaltitude',

# External editor support
'edit-externally' => 'Islan ang mini nga file gamit ang panluwas nga aplikasyon',
'edit-externally-help' => '(Tan-awa ang [//www.mediawiki.org/wiki/Manual:External_editors mga pama-agi sa paghanda kag pag-ayos] para sa mga dugang nga impormasyon)',

# 'all' in various places, this might be different for inflected languages
'watchlistall2' => 'tanan',
'namespacesall' => 'tanan',
'monthsall' => 'tanan',

# Watchlist editing tools
'watchlisttools-view' => 'Tan-awon ang mga kapareho nga ginbag-o',
'watchlisttools-edit' => 'Tan-awon kag islan ang listahan sang balantayan',
'watchlisttools-raw' => 'Liwaton ang hilaw nga listahan sang mga ginabantayan',

# Special:SpecialPages
'specialpages' => 'Pinasahi nga mga pahina',

# Special:Tags
'tag-filter' => '[[Special:Tags|Tatakan]] ang pansala:',

);
